@@ -192,7 +192,7 @@ def __mergerPartFiles__(files, filepath):
 
 def __checkFiles__(files):
     for item in files:
-        if os.path.isfile(files):
+        if os.path.isfile(item):
             continue
         else:
             return False
